@@ -9,7 +9,7 @@ load test_helper/redhatcop-bats-library/src/error-handling
 get_value_from() {
   value=$(echo "${1}" | jq -r "${2}")
 
-  if [[ -z "${value}" ]] ; then
+  if [[ -z "${value}" ]]; then
     fail "# FATAL-ERROR: get_value_from: value is empty or invalid" || return $?
   fi
 
@@ -45,9 +45,27 @@ get_value_from() {
   [[ "${count}" == "6" ]]
 }
 
+@test "template-kubeconform" {
+  tmp="tests/checks/kubeconform.yml"
+  cmd="${KUBE_LINTER_BIN} lint --config e2etests/testdata/kubeconform-config.yaml --do-not-auto-add-defaults --format json ${tmp}"
+  run ${cmd}
+
+  print_info "${status}" "${output}" "${cmd}" "${tmp}"
+  [ "$status" -eq 1 ]
+
+  message1=$(get_value_from "${lines[0]}" '.Reports[0].Object.K8sObject.GroupVersionKind.Kind + ": " + .Reports[0].Diagnostic.Message')
+  message2=$(get_value_from "${lines[0]}" '.Reports[1].Object.K8sObject.GroupVersionKind.Kind + ": " + .Reports[1].Diagnostic.Message')
+  count=$(get_value_from "${lines[0]}" '.Reports | length')
+
+  # Should find 2 validation errors: DaemonSet with replicas field and Pod with invalid field
+  [[ "${count}" == "2" ]]
+  [[ "${message1}" =~ "DaemonSet: resource is not valid:" ]]
+  [[ "${message2}" =~ "Pod: resource is not valid:" ]]
+}
+
 @test "template-check-installed-bash-version" {
-    run "bash --version"
-    [[ "${BASH_VERSION:0:1}" -ge '4' ]] || false
+  run "bash --version"
+  [[ "${BASH_VERSION:0:1}" -ge '4' ]] || false
 }
 
 @test "access-to-create-pods" {
@@ -300,6 +318,25 @@ get_value_from() {
   [[ "${count}" == "2" ]]
 }
 
+@test "env-value-from" {
+  tmp="tests/checks/env-var-value-from.yml"
+  cmd="${KUBE_LINTER_BIN} lint --include env-value-from --do-not-auto-add-defaults --format json ${tmp}"
+  run ${cmd}
+  print_info "${status}" "${output}" "${cmd}" "${tmp}"
+  [ "$status" -eq 1 ]
+  message1=$(get_value_from "${lines[0]}" '.Reports[0].Object.K8sObject.GroupVersionKind.Kind + ": " + .Reports[0].Diagnostic.Message')
+  message2=$(get_value_from "${lines[0]}" '.Reports[1].Object.K8sObject.GroupVersionKind.Kind + ": " + .Reports[1].Diagnostic.Message')
+  message3=$(get_value_from "${lines[0]}" '.Reports[2].Object.K8sObject.GroupVersionKind.Kind + ": " + .Reports[2].Diagnostic.Message')
+  message4=$(get_value_from "${lines[0]}" '.Reports[3].Object.K8sObject.GroupVersionKind.Kind + ": " + .Reports[3].Diagnostic.Message')
+  count=$(get_value_from "${lines[0]}" '.Reports | length')
+
+  [[ "${message1}" == "Deployment: The container \"app\" is referring to an unknown key \"chimpmunk\" in secret \"secretsquirrels\"" ]]
+  [[ "${message2}" == "Deployment: The container \"app\" is referring to an unknown key \"configkey-wrong\" in config map \"testconfig\"" ]]
+  [[ "${message3}" == "Deployment: The container \"app\" is referring to an unknown config map \"missingconfig\"" ]]
+  [[ "${message4}" == "Deployment: The container \"app\" is referring to an unknown secret \"missingsecret\"" ]]
+  [[ "${count}" == "4" ]]
+}
+
 @test "env-var-secret" {
   tmp="tests/checks/env-var-secret.yml"
   cmd="${KUBE_LINTER_BIN} lint --include env-var-secret --do-not-auto-add-defaults --format json ${tmp}"
@@ -411,8 +448,7 @@ get_value_from() {
 
   # TODO: export to helper function so that it can be used for other tests
   actual_messages=()
-  for (( i=0; i<$((count)); i++ ))
-  do
+  for ((i = 0; i < $((count)); i++)); do
     actual_message=$(get_value_from "${lines[0]}" ".Reports[${i}] | .Object.K8sObject.GroupVersionKind.Kind + \": \" + .Diagnostic.Message")
     actual_messages+=("${actual_message}")
   done
@@ -476,7 +512,6 @@ get_value_from() {
   [[ "${count}" == "4" ]]
 }
 
-
 @test "minimum-three-replicas" {
   tmp="tests/checks/minimum-three-replicas.yml"
   cmd="${KUBE_LINTER_BIN} lint --include minimum-three-replicas --do-not-auto-add-defaults --format json ${tmp}"
@@ -680,7 +715,6 @@ get_value_from() {
   cmd="${KUBE_LINTER_BIN} lint --include pdb-min-available --do-not-auto-add-defaults --format json ${tmp}"
   run ${cmd}
 
-
   message1=$(get_value_from "${lines[0]}" '.Reports[0].Object.K8sObject.GroupVersionKind.Kind + ": " + .Reports[0].Diagnostic.Message')
   message2=$(get_value_from "${lines[0]}" '.Reports[1].Object.K8sObject.GroupVersionKind.Kind + ": " + .Reports[1].Diagnostic.Message')
   message3=$(get_value_from "${lines[0]}" '.Reports[2].Object.K8sObject.GroupVersionKind.Kind + ": " + .Reports[2].Diagnostic.Message')
@@ -909,6 +943,24 @@ get_value_from() {
   [[ "${count}" == "1" ]]
 }
 
+@test "schema-validation" {
+  tmp="tests/checks/kubeconform.yml"
+  cmd="${KUBE_LINTER_BIN} lint --config e2etests/testdata/schema-validation-config.yaml --do-not-auto-add-defaults --format json ${tmp}"
+  run ${cmd}
+
+  print_info "${status}" "${output}" "${cmd}" "${tmp}"
+  [ "$status" -eq 1 ]
+
+  message1=$(get_value_from "${lines[0]}" '.Reports[0].Object.K8sObject.GroupVersionKind.Kind + ": " + .Reports[0].Diagnostic.Message')
+  message2=$(get_value_from "${lines[0]}" '.Reports[1].Object.K8sObject.GroupVersionKind.Kind + ": " + .Reports[1].Diagnostic.Message')
+  count=$(get_value_from "${lines[0]}" '.Reports | length')
+
+  # Should find 2 validation errors using builtin schema-validation check
+  [[ "${count}" == "2" ]]
+  [[ "${message1}" =~ "DaemonSet: resource is not valid:" ]]
+  [[ "${message2}" =~ "Pod: resource is not valid:" ]]
+}
+
 @test "sensitive-host-mounts" {
   tmp="tests/checks/sensitive-host-mounts.yml"
   cmd="${KUBE_LINTER_BIN} lint --include sensitive-host-mounts --do-not-auto-add-defaults --format json ${tmp}"
@@ -926,6 +978,25 @@ get_value_from() {
   [[ "${count}" == "2" ]]
 }
 
+@test "sorted-keys" {
+  tmp="tests/checks/sorted-keys.yaml"
+  cmd="${KUBE_LINTER_BIN} lint --include sorted-keys --do-not-auto-add-defaults --format json ${tmp}"
+  run ${cmd}
+
+  print_info "${status}" "${output}" "${cmd}" "${tmp}"
+  [ "$status" -eq 1 ]
+
+  message1=$(get_value_from "${lines[0]}" '.Reports[0].Object.K8sObject.GroupVersionKind.Kind + ": " + .Reports[0].Diagnostic.Message')
+  message2=$(get_value_from "${lines[0]}" '.Reports[1].Object.K8sObject.GroupVersionKind.Kind + ": " + .Reports[1].Diagnostic.Message')
+  message3=$(get_value_from "${lines[0]}" '.Reports[2].Object.K8sObject.GroupVersionKind.Kind + ": " + .Reports[2].Diagnostic.Message')
+  count=$(get_value_from "${lines[0]}" '.Reports | length')
+
+  [[ "${message1}" == "Deployment: Keys are not sorted at spec.template.spec.containers[0]. Expected order: [image, name, ports], got: [name, image, ports]" ]]
+  [[ "${message2}" == "Deployment: Keys are not sorted at root. Expected order: [apiVersion, kind, metadata, spec], got: [apiVersion, metadata, spec, kind]" ]]
+  [[ "${message3}" == "Deployment: Keys are not sorted at spec.template. Expected order: [metadata, spec], got: [spec, metadata]" ]]
+  [[ "${count}" == "27" ]]
+}
+
 @test "ssh-port" {
   tmp="tests/checks/ssh-port.yml"
   cmd="${KUBE_LINTER_BIN} lint --include ssh-port --do-not-auto-add-defaults --format json ${tmp}"
@@ -1100,7 +1171,7 @@ get_value_from() {
 
 @test "flag-ignore-paths" {
   tmp="."
-  cmd="${KUBE_LINTER_BIN} lint --ignore-paths \"tests/**\" --ignore-paths \"e2etests/**\" ${tmp}"
+  cmd="${KUBE_LINTER_BIN} lint --ignore-paths \"tests/**\" --ignore-paths \"e2etests/**\" --ignore-paths \"pkg/**/testdata/**\" ${tmp}"
   run ${cmd}
   print_info "${status}" "${output}" "${cmd}" "${tmp}"
   [ "$status" -eq 0 ]
@@ -1127,3 +1198,23 @@ get_value_from() {
   [[ "${count}" == "1" ]]
 }
 
+@test "flag-kustomize-support" {
+  tmp="tests/testdata/mykustomize"
+  cmd="${KUBE_LINTER_BIN} lint --format json ${tmp}"
+  run ${cmd}
+
+  print_info "${status}" "${output}" "${cmd}" "${tmp}"
+  [ "$status" -eq 1 ]
+
+  # Verify that kustomize manifests were rendered and linted
+  deployment_name=$(get_value_from "${lines[0]}" '.Reports[0].Object.K8sObject.Name')
+  deployment_kind=$(get_value_from "${lines[0]}" '.Reports[0].Object.K8sObject.GroupVersionKind.Kind')
+  count=$(get_value_from "${lines[0]}" '.Reports | length')
+
+  # The deployment name should have the kustomize namePrefix applied
+  [[ "${deployment_name}" == "kustomize-test-deployment" ]]
+  [[ "${deployment_kind}" == "Deployment" ]]
+  # There should be lint errors for the deployment
+  [[ "${count}" -ge 1 ]]
+}
+
