@@ -1,16 +1,13 @@
 package configresolver
 
 import (
-	"path/filepath"
-
-	"github.com/mitchellh/go-homedir"
-	"github.com/pkg/errors"
 	"golang.stackrox.io/kube-linter/internal/defaultchecks"
 	"golang.stackrox.io/kube-linter/internal/errorhelpers"
 	"golang.stackrox.io/kube-linter/internal/set"
 	"golang.stackrox.io/kube-linter/pkg/builtinchecks"
 	"golang.stackrox.io/kube-linter/pkg/checkregistry"
 	"golang.stackrox.io/kube-linter/pkg/config"
+	"golang.stackrox.io/kube-linter/pkg/pathutil"
 )
 
 // LoadCustomChecksInto loads the custom checks from the config into the check registry.
@@ -65,7 +62,7 @@ func GetIgnorePaths(cfg *config.Config) ([]string, error) {
 	errorList := errorhelpers.NewErrorList("check ignore paths")
 	ignorePaths := set.NewStringSet()
 	for _, path := range cfg.Checks.IgnorePaths {
-		res, err := getIgnorePath(path)
+		res, err := pathutil.GetAbsolutPath(path)
 		if err != nil {
 			errorList.AddError(err)
 			continue
@@ -80,22 +77,3 @@ func GetIgnorePaths(cfg *config.Config) ([]string, error) {
 		return i < j
 	}), nil
 }
-
-func getIgnorePath(path string) (string, error) {
-	switch {
-	case path[0] == '~':
-		expandedPath, err := homedir.Expand(path)
-		if err != nil {
-			return "", errors.Wrapf(err, "could not expand path: %q", expandedPath)
-		}
-		return expandedPath, nil
-	case !filepath.IsAbs(path):
-		absPath, err := filepath.Abs(path)
-		if err != nil {
-			return "", errors.Wrapf(err, "could not expand non-absolute path: %q", absPath)
-		}
-		return absPath, nil
-	default:
-		return path, nil
-	}
-}
