@@ -4,6 +4,7 @@ import (
 	"reflect"
 
 	ocsAppsV1 "github.com/openshift/api/apps/v1"
+	"golang.stackrox.io/kube-linter/pkg/extract/customtypes"
 	"golang.stackrox.io/kube-linter/pkg/k8sutil"
 	batchV1 "k8s.io/api/batch/v1"
 	batchV1Beta1 "k8s.io/api/batch/v1beta1"
@@ -45,12 +46,12 @@ func PodTemplateSpec(obj k8sutil.Object) (coreV1.PodTemplateSpec, bool) {
 }
 
 // PodSpec extracts a pod spec from the given object, if available.
-func PodSpec(obj k8sutil.Object) (coreV1.PodSpec, bool) {
+func PodSpec(obj k8sutil.Object) (customtypes.PodSpec, bool) {
 	podTemplateSpec, found := PodTemplateSpec(obj)
 	if !found {
-		return coreV1.PodSpec{}, false
+		return customtypes.PodSpec{}, false
 	}
-	return podTemplateSpec.Spec, true
+	return customtypes.PodSpec{PodSpec: podTemplateSpec.Spec}, true
 }
 
 // Selector extracts a selector from the given object, if available.
